gchecky.model.archive_order_t

Package gchecky :: Module model :: Class archive_order_t |
[hide private]
[frames] | no frames]

# Class archive_order_t

source code

    object --+
             |
     gxml.Node --+
                 |
     gxml.Document --+
                     |
      abstract_order_t --+
                         |
                        archive_order_t

Represents a request to archive a particular order. You would archive an order to remove it from your Merchant Center Inbox, indicating that the order has been delivered.

    >>> test_document(archive_order_t(google_order_number = '841171949013218'),
    ...     '''<archive-order xmlns="http://checkout.google.com/schema/2"
    ...                       google-order-number="841171949013218" />'''
    ... )

Nested Classes | [hide private]
Inherited from `gxml.Document`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Document`: `__str__`, `toxml` Inherited from `gxml.Node`: `__eq__`, `__init__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Methods | [hide private]
Inherited from `gxml.Document`: `fromxml` Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| tag_name = ``'``archive-order``'`` The document's unique xml tag name.
Inherited from `abstract_order_t`: `google_order_number` Inherited from `abstract_order_t` (private): `_fields`

Properties | [hide private]
Inherited from `object`: `__class__`